@@ -18,6 +18,7 @@ _LOGGER = logging.getLogger(__name__)
 
 
 DATA_ENDPOINTS: Dict[str, Any] = {
+    "": {"version": 2},
     "battery-status": {"version": 2},
     "charge-history": {"version": 1},
     "charge-mode": {"version": 1},
@@ -284,7 +285,7 @@ async def get_vehicle_data(
         version=endpoint_version or _get_endpoint_version(DATA_ENDPOINTS[endpoint]),
         vin=vin,
     )
-    url = f"{car_adapter_url}/{endpoint}"
+    url = f"{car_adapter_url}/{endpoint}" if endpoint else car_adapter_url
     params = params or {}
     params["country"] = country
     return cast(
