@@ -46,15 +46,11 @@ COMMON_ERRRORS: List[Dict[str, Any]] = [
 ]
 
 VEHICLE_SPECIFICATIONS: Dict[str, Dict[str, Any]] = {
-    "X071VE": {  # TWINGO III
-        "support-endpoint-hvac-status": False,
-    },
     "X101VE": {  # ZOE phase 1
         "reports-in-watts": True,
         "support-endpoint-location": False,
     },
     "X102VE": {  # ZOE phase 2
-        "support-endpoint-hvac-status": False,
         "warns-on-method-set_ac_stop": "Action `cancel` on endpoint `hvac-start` may not be supported on this model.",  # noqa
     },
     "XJB1SU": {  # CAPTUR II
@@ -62,13 +58,20 @@ VEHICLE_SPECIFICATIONS: Dict[str, Dict[str, Any]] = {
     },
 }
 
+GATEWAY_SPECIFICATIONS: Dict[str, Dict[str, Any]] = {
+    "GDC": {  # ZOE phase 1
+        "reports-in-watts": True,
+        "support-endpoint-location": False,
+    },
+}
+
 
 @dataclass
 class KamereonResponseError(BaseModel):
     """Kamereon response error."""
 
-    errorCode: Optional[str]  # noqa: N815
-    errorMessage: Optional[str]  # noqa: N815
+    errorCode: Optional[str]
+    errorMessage: Optional[str]
 
     def raise_for_error_code(self) -> None:
         """Raise exception from response error."""
@@ -122,9 +125,9 @@ class KamereonResponse(BaseModel):
 class KamereonPersonAccount(BaseModel):
     """Kamereon person account data."""
 
-    accountId: Optional[str]  # noqa: N815
-    accountType: Optional[str]  # noqa: N815
-    accountStatus: Optional[str]  # noqa: N815
+    accountId: Optional[str]
+    accountType: Optional[str]
+    accountStatus: Optional[str]
 
 
 @dataclass
@@ -148,12 +151,12 @@ class KamereonVehicleDetails(BaseModel):
     """Kamereon vehicle details."""
 
     vin: Optional[str]
-    registrationNumber: Optional[str]  # noqa: N815
-    radioCode: Optional[str]  # noqa: N815
+    registrationNumber: Optional[str]
+    radioCode: Optional[str]
     brand: Optional[KamereonVehicleDetailsGroup]
     model: Optional[KamereonVehicleDetailsGroup]
     energy: Optional[KamereonVehicleDetailsGroup]
-    engineEnergyType: Optional[str]  # noqa: N815
+    engineEnergyType: Optional[str]
 
     def get_energy_code(self) -> Optional[str]:
         """Return vehicle energy code."""
@@ -222,16 +225,16 @@ class KamereonVehiclesLink(BaseModel):
     """Kamereon vehicles link data."""
 
     vin: Optional[str]
-    vehicleDetails: Optional[KamereonVehicleDetails]  # noqa: N815
+    vehicleDetails: Optional[KamereonVehicleDetails]
 
 
 @dataclass
 class KamereonVehiclesResponse(KamereonResponse):
     """Kamereon response to GET on /accounts/{account_id}/vehicles."""
 
-    accountId: Optional[str]  # noqa: N815
+    accountId: Optional[str]
     country: Optional[str]
-    vehicleLinks: Optional[List[KamereonVehiclesLink]]  # noqa: N815
+    vehicleLinks: Optional[List[KamereonVehiclesLink]]
 
 
 @dataclass
@@ -249,14 +252,14 @@ class KamereonVehicleContract(BaseModel):
     """Kamereon vehicle contract."""
 
     type: Optional[str]
-    contractId: Optional[str]  # noqa: N815
+    contractId: Optional[str]
     code: Optional[str]
     group: Optional[str]
-    durationMonths: Optional[int]  # noqa: N815
-    startDate: Optional[str]  # noqa: N815
-    endDate: Optional[str]  # noqa: N815
+    durationMonths: Optional[int]
+    startDate: Optional[str]
+    endDate: Optional[str]
     status: Optional[str]
-    statusLabel: Optional[str]  # noqa: N815
+    statusLabel: Optional[str]
     description: Optional[str]
 
 
@@ -264,7 +267,7 @@ class KamereonVehicleContract(BaseModel):
 class KamereonVehicleContractsResponse(KamereonResponse):
     """Kamereon response to GET on /accounts/{accountId}/vehicles/{vin}/contracts."""
 
-    contractList: Optional[List[KamereonVehicleContract]]  # noqa: N815
+    contractList: Optional[List[KamereonVehicleContract]]
 
 
 @dataclass
@@ -296,15 +299,15 @@ class KamereonVehicleBatteryStatusData(KamereonVehicleDataAttributes):
     """Kamereon vehicle battery-status data."""
 
     timestamp: Optional[str]
-    batteryLevel: Optional[int]  # noqa: N815
-    batteryTemperature: Optional[int]  # noqa: N815
-    batteryAutonomy: Optional[int]  # noqa: N815
-    batteryCapacity: Optional[int]  # noqa: N815
-    batteryAvailableEnergy: Optional[int]  # noqa: N815
-    plugStatus: Optional[int]  # noqa: N815
-    chargingStatus: Optional[float]  # noqa: N815
-    chargingRemainingTime: Optional[int]  # noqa: N815
-    chargingInstantaneousPower: Optional[float]  # noqa: N815
+    batteryLevel: Optional[int]
+    batteryTemperature: Optional[int]
+    batteryAutonomy: Optional[int]
+    batteryCapacity: Optional[int]
+    batteryAvailableEnergy: Optional[int]
+    plugStatus: Optional[int]
+    chargingStatus: Optional[float]
+    chargingRemainingTime: Optional[int]
+    chargingInstantaneousPower: Optional[float]
 
     def get_plug_status(self) -> Optional[enums.PlugState]:
         """Return plug status."""
@@ -339,34 +342,36 @@ class KamereonVehicleBatteryStatusData(KamereonVehicleDataAttributes):
 class KamereonVehicleLocationData(KamereonVehicleDataAttributes):
     """Kamereon vehicle data location attributes."""
 
-    lastUpdateTime: Optional[str]  # noqa: N815
-    gpsLatitude: Optional[float]  # noqa: N815
-    gpsLongitude: Optional[float]  # noqa: N815
+    lastUpdateTime: Optional[str]
+    gpsLatitude: Optional[float]
+    gpsLongitude: Optional[float]
 
 
 @dataclass
 class KamereonVehicleHvacStatusData(KamereonVehicleDataAttributes):
     """Kamereon vehicle data hvac-status attributes."""
 
-    externalTemperature: Optional[float]  # noqa: N815
-    hvacStatus: Optional[str]  # noqa: N815
-    nextHvacStartDate: Optional[str]  # noqa: N815
+    lastUpdateTime: Optional[str]
+    externalTemperature: Optional[float]
+    hvacStatus: Optional[str]
+    nextHvacStartDate: Optional[str]
+    socThreshold: Optional[float]
 
 
 @dataclass
 class KamereonVehicleChargeModeData(KamereonVehicleDataAttributes):
     """Kamereon vehicle data charge-mode attributes."""
 
-    chargeMode: Optional[str]  # noqa: N815
+    chargeMode: Optional[str]
 
 
 @dataclass
 class KamereonVehicleCockpitData(KamereonVehicleDataAttributes):
     """Kamereon vehicle data cockpit attributes."""
 
-    fuelAutonomy: Optional[float]  # noqa: N815
-    fuelQuantity: Optional[float]  # noqa: N815
-    totalMileage: Optional[float]  # noqa: N815
+    fuelAutonomy: Optional[float]
+    fuelQuantity: Optional[float]
+    totalMileage: Optional[float]
 
 
 @dataclass
@@ -374,11 +379,77 @@ class KamereonVehicleLockStatusData(KamereonVehicleDataAttributes):
     """Kamereon vehicle data lock-status attributes."""
 
 
+@dataclass
+class KamereonVehicleCarAdapterData(KamereonVehicleDataAttributes):
+    """Kamereon vehicle data hvac-status attributes."""
+
+    vin: Optional[str]
+    vehicleId: Optional[int]
+    batteryCode: Optional[str]
+    brand: Optional[str]
+    canGeneration: Optional[str]
+    carGateway: Optional[str]
+    deliveryCountry: Optional[str]
+    deliveryDate: Optional[str]
+    energy: Optional[str]
+    engineType: Optional[str]
+    familyCode: Optional[str]
+    firstRegistrationDate: Optional[str]
+    gearbox: Optional[str]
+    modelCode: Optional[str]
+    modelCodeDetail: Optional[str]
+    modelName: Optional[str]
+    radioType: Optional[str]
+    region: Optional[str]
+    registrationCountry: Optional[str]
+    registrationNumber: Optional[str]
+    tcuCode: Optional[str]
+    versionCode: Optional[str]
+    privacyMode: Optional[str]
+    privacyModeUpdateDate: Optional[str]
+    svtFlag: Optional[bool]
+    svtBlockFlag: Optional[bool]
+
+    def uses_electricity(self) -> bool:
+        """Return True if model uses electricity."""
+        if self.energy in [
+            "electric",
+        ]:
+            return True
+        return False
+
+    def uses_fuel(self) -> bool:
+        """Return True if model uses fuel."""
+        if self.energy in [
+            "gasoline",
+        ]:
+            return True
+        return False
+
+    def reports_charging_power_in_watts(self) -> bool:
+        """Return True if model reports chargingInstantaneousPower in watts."""
+        # Default to False for unknown vehicles
+        if self.carGateway:
+            return GATEWAY_SPECIFICATIONS.get(self.carGateway, {}).get(
+                "reports-in-watts", False
+            )
+        return False  # pragma: no cover
+
+    def supports_endpoint(self, endpoint: str) -> bool:
+        """Return True if model supports specified endpoint."""
+        # Default to True for unknown vehicles
+        if self.carGateway:
+            return GATEWAY_SPECIFICATIONS.get(self.carGateway, {}).get(
+                f"support-endpoint-{endpoint}", True
+            )
+        return True  # pragma: no cover
+
+
 @dataclass
 class ChargeDaySchedule(BaseModel):
     """Kamereon vehicle charge schedule for day."""
 
-    startTime: Optional[str]  # noqa: N815
+    startTime: Optional[str]
     duration: Optional[int]
 
     def for_json(self) -> Dict[str, Any]:
@@ -428,7 +499,7 @@ class ChargeSchedule(BaseModel):
 class HvacDaySchedule(BaseModel):
     """Kamereon vehicle hvac schedule for day."""
 
-    readyAtTime: Optional[str]  # noqa: N815
+    readyAtTime: Optional[str]
 
     def for_json(self) -> Dict[str, Optional[str]]:
         """Create dict for json."""
